@@ -1,6 +1,6 @@
 from collections import namedtuple
 
-from pybliometrics.scopus.classes import Retrieval
+from pybliometrics.scopus.superclasses import Retrieval
 from pybliometrics.scopus.utils import chained_get, get_id, get_link,\
     parse_date_created
 
@@ -130,6 +130,10 @@ class ContentAffiliationRetrieval(Retrieval):
             is passed, cached file will be refreshed if the number of days
             since last modification exceeds that value.
 
+        Examples
+        --------
+        See https://pybliometrics.readthedocs.io/en/stable/examples/ContentAffiliationRetrieval.html.
+
         Notes
         -----
         The directory for cached results is `{path}/STANDARD/{aff_id}`,
@@ -142,9 +146,7 @@ class ContentAffiliationRetrieval(Retrieval):
         self._json = self._json['affiliation-retrieval-response']
 
     def __str__(self):
-        s = '''{self.affiliation_name}
-    ({self.author_count} authors, {self.document_count} documents)
-    {self.address}
-    {self.city}, {self.country}
-    {self.url}'''.format(self=self)
+        s = f"{self.affiliation_name} ({int(self.author_count):,} authors, "\
+            f"{int(self.document_count):,} documents)\n"\
+            f"{self.address}\n {self.city}, {self.country}\n{self.url}"""
         return s
