@@ -1,8 +1,8 @@
 from collections import namedtuple
 
-from pybliometrics.scopus.classes import Search
-from pybliometrics.scopus.utils import check_integrity, check_integrity_params,\
-    check_field_consistency
+from pybliometrics.scopus.superclasses import Search
+from pybliometrics.scopus.utils import check_integrity,\
+    check_integrity_params, check_field_consistency, make_search_summary
 
 
 class AffiliationSearch(Search):
@@ -88,6 +88,10 @@ class AffiliationSearch(Search):
         ValueError
             If the integrity_action parameter is not one of the allowed ones.
 
+        Examples
+        --------
+        See https://pybliometrics.readthedocs.io/en/stable/examples/AffiliationSearch.html.
+
         Notes
         -----
         The directory for cached results is `{path}/STANDARD/{fname}`,
@@ -106,6 +110,5 @@ class AffiliationSearch(Search):
         self.action = integrity_action
 
     def __str__(self):
-        s = """Search {} yielded {} affiliation(s):\n    {}"""
-        return s.format(self.query, len(self._json),
-                        entries='\n    '.join([str(a) for a in self._json]))
+        res = [a['affiliation-name'] for a in self._json]
+        return make_search_summary(self, "affiliation", res)
