@@ -5,7 +5,7 @@ from json import loads
 
 from .author_search import AuthorSearch
 from .scopus_search import ScopusSearch
-from pybliometrics.scopus.classes import Retrieval
+from pybliometrics.scopus.superclasses import Retrieval
 from pybliometrics.scopus.utils import chained_get, get_content, get_link,\
     listify, parse_affiliation, parse_date_created
 
@@ -78,7 +78,10 @@ class AuthorRetrieval(Retrieval):
 
     @property
     def eid(self):
-        """The EID of the author.  Might differ from the one provided."""
+        """The EID of the author.  If it differs from the one provided,
+        pybliometrics will throw a warning informing the user about
+        author profile merges.
+        """
         return self._json['coredata']['eid']
 
     @property
@@ -103,9 +106,9 @@ class AuthorRetrieval(Retrieval):
         """The author's ID.  Might differ from the one provided."""
         ident = self._json['coredata']['dc:identifier'].split(":")[-1]
         if ident != self._id:
-            text = "Profile with ID {} has been merged and the new ID is "\
-                   "{}.  Please update your records manually.  Files have "\
-                   "been cached with the old ID.".format(self._id, ident)
+            text = f"Profile with ID {self._id} has been merged and the new "\
+                   f"ID is {ident}.  Please update your records manually.  "\
+                   "Files have been cached with the old ID."
             warn(text, UserWarning)
         return ident
 
@@ -218,6 +221,10 @@ class AuthorRetrieval(Retrieval):
             is passed, cached file will be refreshed if the number of days
             since last modification exceeds that value.
 
+        Examples
+        --------
+        See https://pybliometrics.readthedocs.io/en/stable/examples/AuthorRetrieval.html
+
         Notes
         -----
         The directory for cached results is `{path}/ENHANCED/{author_id}`,
@@ -236,21 +243,20 @@ class AuthorRetrieval(Retrieval):
         except KeyError:  # Incomplete forward
             alias_json = listify(self._json['alias']['prism:url'])
             alias = ', '.join([d['$'].split(':')[-1] for d in alias_json])
-            text = 'Author profile with ID {} has been merged and the main '\
-                   'profile is now one of {}.  Please update your records '\
-                   'manually.  Functionality of this object is '\
-                   'reduced.'.format(author_id, alias)
+            text = f'Author profile with ID {author_id} has been merged and '\
+                   f'the main profile is now one of {alias}.  Please update '\
+                   'your records manually.  Functionality of this object is '\
+                   'reduced.'
             warn(text, UserWarning)
 
     def __str__(self):
         """Return a summary string."""
-        s = '''{self.indexed_name} from {self.affiliation_current},
-    published {self.document_count} documents since {since}
-    in {journals} distinct journals
-    which were cited by {self.cited_by_count} authors
-    in {self.citation_count} documents
-    '''.format(self=self, since=self.publication_range[0],
-               journals=len(self.journal_history))
+        s = f"{self.indexed_name} from {self.affiliation_current[0].preferred_name},"\
+            f"\npublished {int(self.document_count):,} document(s) since "\
+            f"{self.publication_range[0]} in {len(self.journal_history):,} "\
+            "distinct source(s),\nwhich were cited by "\
+            f"{int(self.cited_by_count):,} author(s) in "\
+            f"{int(self.citation_count):,} document(s)"
         return s
 
     def get_coauthors(self):
@@ -261,6 +267,7 @@ class AuthorRetrieval(Retrieval):
         Note: These information will not be cached and are slow for large
         coauthor groups.
         """
+        SIZE = 25
         # Get number of authors to search for
         url = self.coauthor_link
         res = get_content(url=url)
@@ -271,7 +278,7 @@ class AuthorRetrieval(Retrieval):
         coauth = namedtuple('Coauthor', fields)
         coauthors = []
         # Iterate over search results in chunks of 25 results
-        count = 25
+        count = SIZE
         start = 0
         while start < N:
             params = {'start': start, 'count': count}
@@ -292,7 +299,7 @@ class AuthorRetrieval(Retrieval):
                     city=aff.get('affiliation-city'),
                     country=aff.get('affiliation-country'))
                 coauthors.append(new)
-            count += 25
+            start += SIZE
         return coauthors or None
 
     def get_documents(self, subtypes=None, **kwds):
@@ -312,7 +319,7 @@ class AuthorRetrieval(Retrieval):
         results : list of namedtuple
             The same type of results returned from any ScopusSearch().
         """
-        s = ScopusSearch('AU-ID({})'.format(self.identifier), **kwds)
+        s = ScopusSearch(f'AU-ID({self.identifier})', **kwds)
         if subtypes:
             return [p for p in s.results if p.subtype in subtypes]
         else:
@@ -322,10 +329,10 @@ class AuthorRetrieval(Retrieval):
         """Return list of EIDs of the author's publications using
         a ScopusSearch() query.
         """
-        s = ScopusSearch('AU-ID({})'.format(self.identifier), *args, **kwds)
+        s = ScopusSearch(f'AU-ID({self.identifier})', *args, **kwds)
         return s.get_eids()
 
-    def estimate_uniqueness(self, query=None, **kwds):
+    def estimate_uniqueness(self, query=None, *args, **kwds):
         """Estimate how unqiue a profile is by get the number of
         matches of an AuthorSearch for this person.
 
@@ -338,20 +345,15 @@ class AuthorRetrieval(Retrieval):
             "SUBJAREA()" OR "AF-ID() AND SUBJAREA()".  For details see
             https://dev.elsevier.com/tips/AuthorSearchTips.htm.
 
-        **kwds : dict-like
-            Parameters to be passed on to ScopusSearch().
+        args, kwds : key-value pairings
+            Parameters to be passed on to AuthorSearch().
 
         Returns
         -------
         n : int
             The number of matches of the query.
-
-        Notes
-        -----
-        If download=True, the search files are cached with AuthorSearch().
         """
         if not query:
-            query = "AUTHLAST({}) AND AUTHFIRST({})".format(
-                self.surname, self.given_name)
+            query = f"AUTHLAST({self.surname}) AND AUTHFIRST({self.given_name})"
         s = AuthorSearch(query, **kwds)
         return s.get_results_size()
