@@ -1,8 +1,8 @@
 from collections import namedtuple
 
-from pybliometrics.scopus.classes import Search
+from pybliometrics.scopus.superclasses import Search
 from pybliometrics.scopus.utils import check_integrity, check_integrity_params,\
-    check_field_consistency, listify
+    check_field_consistency, listify, make_search_summary
 
 
 class ScopusSearch(Search):
@@ -47,14 +47,10 @@ class ScopusSearch(Search):
         for item in self._json:
             info = {}
             # Parse affiliations
-            try:
-                info["affilname"] = _join(item['affiliation'], 'affilname')
-                info["afid"] = _join(item['affiliation'], 'afid')
-                info["aff_city"] = _join(item['affiliation'], 'affiliation-city')
-                info["aff_country"] = _join(item['affiliation'],
-                                            'affiliation-country')
-            except KeyError:
-                pass
+            info["affilname"] = _join(item, 'affilname')
+            info["afid"] = _join(item, 'afid')
+            info["aff_city"] = _join(item, 'affiliation-city')
+            info["aff_country"] = _join(item, 'affiliation-country')
             # Parse authors
             try:
                 # Deduplicate list of authors
@@ -76,11 +72,13 @@ class ScopusSearch(Search):
             if isinstance(date, list):
                 date = date[0].get('$')
             new = doc(article_number=item.get('article-number'),
-                      title=item.get('dc:title'), fund_sponsor=item.get('fund-sponsor'),
-                      subtype=item.get('subtype'), subtypeDescription=item.get('subtypeDescription'),
-                      issn=item.get('prism:issn'),
-                      creator=item.get('dc:creator'), affilname=info.get("affilname"),
-                      author_names=info.get("auth_names"), doi=item.get('prism:doi'),
+                      title=item.get('dc:title'), fund_no=item.get('fund-no'),
+                      fund_sponsor=item.get('fund-sponsor'),
+                      subtype=item.get('subtype'), doi=item.get('prism:doi'),
+                      subtypeDescription=item.get('subtypeDescription'),
+                      issn=item.get('prism:issn'), creator=item.get('dc:creator'),
+                      affilname=info.get("affilname"),
+                      author_names=info.get("auth_names"),
                       coverDate=date, volume=item.get('prism:volume'),
                       coverDisplayDate=item.get('prism:coverDisplayDate'),
                       publicationName=item.get('prism:publicationName'),
@@ -88,7 +86,7 @@ class ScopusSearch(Search):
                       aggregationType=item.get('prism:aggregationType'),
                       issueIdentifier=item.get('prism:issueIdentifier'),
                       pageRange=item.get('prism:pageRange'),
-                      author_afids=info.get("auth_afid"), fund_no=item.get('fund-no'),
+                      author_afids=info.get("auth_afid"),
                       affiliation_country=info.get("aff_country"),
                       citedby_count=item.get('citedby-count'),
                       openaccess=item.get('openaccess'), eIssn=item.get('prism:eIssn'),
@@ -165,6 +163,10 @@ class ScopusSearch(Search):
             If the view or the integrity_action parameter is not one of
             the allowed ones.
 
+        Examples
+        --------
+        See https://pybliometrics.readthedocs.io/en/stable/examples/ScopusSearch.html.
+
         Notes
         -----
         The directory for cached results is `{path}/{view}/{fname}`,
@@ -175,7 +177,7 @@ class ScopusSearch(Search):
         allowed_views = ('STANDARD', 'COMPLETE')
         if view and view not in allowed_views:
             msg = 'view parameter must be one of ' + ', '.join(allowed_views)
-            raise ValueError()
+            raise ValueError(msg)
         check_integrity_params(integrity_action)
 
         # Parameters
@@ -200,9 +202,7 @@ class ScopusSearch(Search):
         self.action = integrity_action
 
     def __str__(self):
-        eids = self.get_eids()
-        s = """Search {} yielded {} document(s):\n    {}"""
-        return s.format(self.query, len(eids), '\n    '.join(eids))
+        return make_search_summary(self, "document", self.get_eids())
 
     def get_eids(self):
         """EIDs of retrieved documents."""
@@ -218,11 +218,14 @@ def _deduplicate(lst):
     return out
 
 
-def _join(lst, key, sep=";"):
+def _join(item, key, sep=";"):
     """Auxiliary function to join same elements of a list of dictionaries if
     the elements are not None.
     """
-    return sep.join([d[key] for d in lst if d[key]])
+    try:
+        return sep.join([d[key] or "" for d in item["affiliation"]])
+    except (KeyError, TypeError):
+        return None
 
 
 def _replace_none(lst, repl=""):
