@@ -1,9 +1,9 @@
 import os
+
 import requests
-from configparser import NoOptionError
 
 from pybliometrics.scopus import exception
-from pybliometrics.scopus.utils import DEFAULT_PATHS, config
+from pybliometrics.scopus.utils import CONFIG_FILE, DEFAULT_PATHS, config
 from pybliometrics.scopus.utils.create_config import create_config
 from pybliometrics import version_info
 
@@ -11,8 +11,8 @@ from pybliometrics import version_info
 user_agent = 'pybliometrics-v' + '.'.join([str(e) for e in version_info[:3]])
 
 errors = {400: exception.Scopus400Error, 401: exception.Scopus401Error,
-          404: exception.Scopus404Error, 429: exception.Scopus429Error,
-          500: exception.Scopus500Error}
+          403: exception.Scopus403Error, 404: exception.Scopus404Error,
+          429: exception.Scopus429Error, 500: exception.Scopus500Error}
 
 
 def get_content(url, params={}, *args, **kwds):
@@ -45,39 +45,45 @@ def get_content(url, params={}, *args, **kwds):
     resp : byte-like object
         The content of the file, which needs to be serialized.
     """
-    # Get credentials and set request headers
-    key = config.get('Authentication', 'APIKey')
-    header = {
-        'X-ELS-APIKey': key,
-        'Accept': 'application/json',
-        'User-Agent': user_agent
-        }
+    from random import shuffle
+
+    from simplejson import JSONDecodeError
+
+    # Set header, params and proxy
+    keys = config.get('Authentication', 'APIKey').split(",")
+    header = {'X-ELS-APIKey': keys[0].strip(),
+              'Accept': 'application/json',
+              'User-Agent': user_agent}
     if config.has_option('Authentication', 'InstToken'):
         token = config.get('Authentication', 'InstToken')
-        header.update({'X-ELS-APIKey': key, 'X-ELS-Insttoken': token})
-    # Perform request
+        header['X-ELS-Insttoken'] = token
     params.update(**kwds)
-    # If config.ini has a section as follows:
-    #
-    # [Proxy]
-    # https = protocol://server:port
-    #
-    # it uses a proxy as defined
-    # see requests documentation for details
-    if config.has_section("Proxy"):
-        proxyDict = dict(config.items("Proxy"))
-        resp = requests.get(url, headers=header, proxies=proxyDict, params=params)
-    else:
-        resp = requests.get(url, headers=header, params=params)
-    # Try raising ScopusError with supplied error message
-    # if no message given, do without supplied error message
-    # at least raise requests error
+    proxies = dict(config._sections.get("Proxy", {}))
+
+    # Perform request, eventually replacing the current key
+    resp = requests.get(url, headers=header, proxies=proxies,
+                        params=params)
+    while resp.status_code == 429:
+        try:
+            keys.pop(0)  # Remove current key
+            shuffle(keys)
+            header['X-ELS-APIKey'] = keys[0].strip()
+            resp = requests.get(url, headers=header, proxies=proxies,
+                                params=params)
+            config['Authentication']['APIKey'] = ",".join(list(keys))
+        except IndexError:  # All keys depleted
+            break
+
+    # Eventually raise error, if possible with supplied error message
     try:
         error_type = errors[resp.status_code]
         try:
             reason = resp.json()['service-error']['status']['statusText']
-        except:
-            reason = ""
+        except (JSONDecodeError, KeyError):
+            try:
+                reason = resp.json()['message']
+            except:
+                reason = ""
         raise errors[resp.status_code](reason)
     except KeyError:
         resp.raise_for_status()
@@ -122,19 +128,23 @@ def detect_id_type(sid):
     try:
         return id_type
     except UnboundLocalError:
-        raise ValueError('ID type detection failed for \'{}\'.'.format(sid))
+        raise ValueError(f'ID type detection failed for "{sid}".')
 
 
 def get_folder(api, view):
     """Auxiliary function to get the cache folder belonging to an API,
     eventually create the folder.
     """
+    from configparser import NoOptionError
     if not config.has_section('Directories'):
         create_config()
     try:
         folder = config.get('Directories', api)
     except NoOptionError:
         folder = DEFAULT_PATHS[api]
+        config.set('Directories', api, folder)
+        with open(CONFIG_FILE, 'w') as f:
+            config.write(f)
     folder = os.path.join(folder, view or '')
     if not os.path.exists(folder):
         os.makedirs(folder)
@@ -143,10 +153,10 @@ def get_folder(api, view):
 
 def print_progress(iteration, total, length=50):
     """Print terminal progress bar."""
-    percent = 100 * (iteration / float(total))
+    share = iteration / float(total)
     filled_len = int(length * iteration // total)
     bar = '█' * filled_len + '-' * (length - filled_len)
-    print('\rProgress: |{}| {:.2f}% Complete'.format(bar, percent), end='\r')
+    print(f'\rProgress: |{bar}| {share:.2%} Complete', end='\r')
     if iteration == total:
         print()
 
