@@ -34,8 +34,8 @@ def check_integrity(tuples, fields, action):
         elements = [getattr(e, field) for e in tuples]
         if None not in elements:
             continue
-        msg = "Parsed information doesn't pass integrity check becaue of "\
-              "incomplete information in field '{}'".format(field)
+        msg = "Parsed information doesn't pass integrity check because of "\
+              f"incomplete information in field '{field}'"
         if action == "raise":
             raise AttributeError(msg)
         elif action == "warn":
@@ -53,8 +53,8 @@ def check_field_consistency(needles, haystack):
     """Raise ValueError if elements of a list are not present in a string."""
     wrong = set(needles) - set(haystack.split())
     if wrong:
-        msg = "Element(s) '{}' not allowed in parameter "\
-              "integrity_fields".format("', '".join(sorted(wrong)))
+        msg = f"Element(s) '{', '.join(sorted(wrong))}' not allowed in "\
+              "parameter integrity_fields"
         raise ValueError(msg)
 
 
@@ -82,6 +82,22 @@ def listify(element):
         return [element]
 
 
+def make_search_summary(self, keyword, results, joiner="\n    "):
+    """Create string for str dunder of search classes."""
+    if self._n != 1:
+        appendix = "s"
+        verb = "have"
+    else:
+        appendix = ""
+        verb = "has"
+    s = f"Search '{self.query}' yielded {self._n:,} {keyword}{appendix}"
+    if results:
+        s += ":" + joiner + joiner.join(results)
+    elif self._n:
+        s += f", which {verb} not been downloaded"
+    return s
+
+
 def parse_affiliation(affs):
     """Helper function to parse list of affiliation-related information."""
     order = 'id parent type relationship afdispname preferred_name '\
